@@ -17,7 +17,7 @@
 package org.kie.workbench.drools.client;
 
 import com.google.gwtmockito.GwtMockitoTestRunner;
-import org.dashbuilder.client.cms.screen.explorer.ContentExplorerScreen;
+import org.dashbuilder.client.cms.screen.explorer.NavigationExplorerScreen;
 import org.dashbuilder.client.navigation.NavigationManager;
 import org.dashbuilder.client.navigation.event.NavTreeLoadedEvent;
 import org.dashbuilder.client.navigation.impl.NavigationManagerImpl;
@@ -90,7 +90,7 @@ public class KieDroolsWorkbenchEntryPointTest {
     private NavigationManager navigationManager;
 
     @Mock
-    protected ContentExplorerScreen contentExplorerScreen;
+    protected NavigationExplorerScreen navigationExplorerScreen;
 
     @Mock
     protected NavigationConstants navigationConstants;
@@ -131,15 +131,16 @@ public class KieDroolsWorkbenchEntryPointTest {
                                                                       menuBar,
                                                                       workbench,
                                                                       permissionTreeSetup,
+                                                                      perspectiveTreeProvider,
                                                                       adminPageHelper,
                                                                       navTreeDefinitions,
                                                                       navigationManager,
-                                                                      contentExplorerScreen));
+                                                                      navigationExplorerScreen));
 
         doNothing().when(kieWorkbenchEntryPoint).hideLoadingPopup();
 
-        navTreeEditor = spy(new NavTreeEditor(mock(NavTreeEditorView.class), null, syncBeanManager, null, perspectiveTreeProvider, targetPerspectiveEditor, null, null, null));
-        when(contentExplorerScreen.getNavTreeEditor()).thenReturn(navTreeEditor);
+        navTreeEditor = spy(new NavTreeEditor(mock(NavTreeEditorView.class), null, syncBeanManager, null, perspectiveTreeProvider, targetPerspectiveEditor, null, null, null, null));
+        when(navigationExplorerScreen.getNavTreeEditor()).thenReturn(navTreeEditor);
     }
 
     @Test
@@ -148,6 +149,7 @@ public class KieDroolsWorkbenchEntryPointTest {
 
         verify(workbench).addStartupBlocker(KieDroolsWorkbenchEntryPoint.class);
         verify(permissionTreeSetup).configureTree();
+        verify(perspectiveTreeProvider).excludePerspectiveId("ContentManagerPerspective");
         verify(navTreeEditor).setMaxLevels(NavTreeDefinitions.GROUP_WORKBENCH, 2);
         verify(navTreeEditor).setNewDividerEnabled(NavTreeDefinitions.GROUP_WORKBENCH, false);
         verify(navTreeEditor).setNewPerspectiveEnabled(NavTreeDefinitions.GROUP_WORKBENCH, false);
@@ -174,28 +176,24 @@ public class KieDroolsWorkbenchEntryPointTest {
 
         NavGroup design = (NavGroup) navTree.getItemById(NavTreeDefinitions.GROUP_DESIGN);
         NavItem projects = navTree.getItemById(NavTreeDefinitions.ENTRY_PROJECTS);
-        NavItem dashboard = navTree.getItemById(NavTreeDefinitions.ENTRY_DASHBOARDS);
 
-        NavGroup devops = (NavGroup) navTree.getItemById(NavTreeDefinitions.GROUP_DEVOPS);
+        NavGroup deploy = (NavGroup) navTree.getItemById(NavTreeDefinitions.GROUP_DEPLOY);
         NavItem execServers = navTree.getItemById(NavTreeDefinitions.ENTRY_EXECUTION_SERVERS);
 
         assertNotNull(workbench);
         assertNotNull(design);
-        assertNotNull(devops);
+        assertNotNull(deploy);
         assertEquals(design.getParent(),
                      workbench);
-        assertEquals(devops.getParent(),
+        assertEquals(deploy.getParent(),
                      workbench);
 
         assertNotNull(projects);
-        assertNotNull(dashboard);
         assertEquals(projects.getParent(),
                      design);
-        assertEquals(dashboard.getParent(),
-                     design);
 
         assertNotNull(execServers);
         assertEquals(execServers.getParent(),
-                     devops);
+                     deploy);
     }
 }
