@@ -1,5 +1,5 @@
 /*
- * Copyright 2015 Red Hat, Inc. and/or its affiliates.
+ * Copyright 2017 Red Hat, Inc. and/or its affiliates.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,15 +15,17 @@
  */
 package org.kie.wb.selenium.model.persps;
 
+import org.jboss.arquillian.graphene.findby.ByJQuery;
 import org.kie.wb.selenium.util.Waits;
 import org.openqa.selenium.By;
 
 public class ProcessDefinitionsPerspective extends AbstractPerspective {
 
-    private static final By PROC_DEFS_TITLE = By.cssSelector("span[title='Process Definitions']");
+    private static final By PROCESS_DEFINITIONS_BREADCRUMB =
+            ByJQuery.selector("[data-field='breadcrumb']:contains('Manage Process Definitions')");
 
     @Override
     public boolean isDisplayed() {
-        return Waits.isElementPresent(PROC_DEFS_TITLE);
+        return Waits.isElementPresent(PROCESS_DEFINITIONS_BREADCRUMB);
     }
 }
